# 1.9.0

  - Redefine the IoU-like metric using arccos distance.

# 1.8.0

  - Add metrics selector.
  - Limit the Python versions to >=3.11.

# 1.7.0

  - Add IoU-like-two-yaw association metric.
  - Make left labels on bar plot one-liners, except `mahalanobis-size-modulated`.
  - Describe and fix the keystroke `2`.


# 1.6.0

  - Calibrating the IoU-like-dia-Mah.
  - Experimental metric using Slater exponent `exp(-d)`.
  - Update dependencies.


# 1.5.0

  - Experimental association metric based on Mahalanobis distance with diagonal covariance.
  - Bugfix the size format wlh means dx, dy, dz with zero rotation.
  - Keystroke 2 results in 4x2 probe box.